package main

import (
	"changeme/controller"
	"embed"

	"github.com/sirupsen/logrus"
	"github.com/wailsapp/wails/v2"
	"github.com/wailsapp/wails/v2/pkg/options"
	"github.com/wailsapp/wails/v2/pkg/options/assetserver"
	"gitter.top/common/lormatter"
)

func init() {
	formatter := &lormatter.Formatter{}
	logrus.SetFormatter(formatter)
	logrus.SetReportCaller(true)
}

//go:embed all:frontend/dist
var assets embed.FS

func main() {
	app := controller.NewStorage()

	err := wails.Run(&options.App{
		Title:  "filer",
		Width:  1024,
		Height: 768,
		AssetServer: &assetserver.Options{
			Assets: assets,
		},
		BackgroundColour: &options.RGBA{R: 27, G: 38, B: 54, A: 1},
		OnStartup:        app.Startup,
		Frameless:        true,
		CSSDragProperty:  "widows",
		CSSDragValue:     "1",
		Bind: []interface{}{
			app,
		},
	})

	if err != nil {
		println("Error:", err.Error())
	}
}
